@@ -268,7 +268,7 @@ private.as.dgTMatrix <- function(M)
     ## Convert into dgTMatrix format of Matrix. Make sure the
     ## representation is unique (ie no double triplets etc)
     ## convert through the 'dgCMatrix'-class to make it unique;
-    return(as(private.as.dgCMatrix(M), "dgTMatrix"))
+    return(as(private.as.dgCMatrix(M), "TsparseMatrix"))
   }
 }
 
@@ -277,10 +277,13 @@ private.as.dgCMatrix <- function(M)
   if(is.null(M) || is(M,"dgCMatrix")){
     return(M)
   } else {
+    if (!inherits(M, "Matrix")) {
+      M <- as(M, "Matrix")
+    }
     ## Convert into dgCMatrix format of Matrix.
     ## Convert via virtual class CsparseMatrix;
     ## this allows more general conversions than direct conversion.
-    return(as(as(as(M, "sparseMatrix"), "CsparseMatrix"), "dgCMatrix"))
+    return(as(as(as(M, "dMatrix"), "generalMatrix"), "CsparseMatrix"))
   }
 }
 
@@ -289,10 +292,13 @@ private.as.dtCMatrix <- function(M)
   if(is.null(M) || is(M,"dtCMatrix")){
     return(M)
   } else {
+    if (!inherits(M, "Matrix")) {
+      M <- as(M, "Matrix")
+    }
     ## Convert into dtCMatrix format of Matrix.
     ## Convert via virtual class CsparseMatrix;
     ## this allows more general conversions than direct conversion.
-    return (as(as(as(M, "CsparseMatrix"), "dgCMatrix"), "dtCMatrix"))
+    return(as(as(as(M, "dMatrix"), "triangularMatrix"), "CsparseMatrix"))
   }
 }
 
@@ -702,3 +708,10 @@ print.summary.excurobj <- function(x,...)
 print.excurobj <- function(x,...) {
   print(summary(x))
 }
+
+
+
+#.onLoad <- function(libname, pkgname) {
+#  # For Matrix coercion deprecation testing: 1=warn, 2=stop, NA=something else
+#  # options(Matrix.warnDeprecatedCoerce = 2)
+#}
